==> huaweicloudsdkeihealth-3.1.138-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/log_content_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class LogContentDto:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'collect_time': 'str',
        'content': 'str'
    }

    attribute_map = {
        'collect_time': 'collect_time',
        'content': 'content'
    }

    def __init__(self, collect_time=None, content=None):
        """LogContentDto

        The model defined in huaweicloud sdk

        :param collect_time: 作业日志采集时间
        :type collect_time: str
        :param content: 作业日志内容
        :type content: str
        """
        
        

        self._collect_time = None
        self._content = None
        self.discriminator = None

        if collect_time is not None:
            self.collect_time = collect_time
        if content is not None:
            self.content = content

    @property
    def collect_time(self):
        """Gets the collect_time of this LogContentDto.

        作业日志采集时间

        :return: The collect_time of this LogContentDto.
        :rtype: str
        """
        return self._collect_time

    @collect_time.setter
    def collect_time(self, collect_time):
        """Sets the collect_time of this LogContentDto.

        作业日志采集时间

        :param collect_time: The collect_time of this LogContentDto.
        :type collect_time: str
        """
        self._collect_time = collect_time

    @property
    def content(self):
        """Gets the content of this LogContentDto.

        作业日志内容

        :return: The content of this LogContentDto.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this LogContentDto.

        作业日志内容

        :param content: The content of this LogContentDto.
        :type content: str
        """
        self._content = content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogContentDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.150-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/log_content_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class LogContentDto:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'collect_time': 'str',
        'content': 'str'
    }

    attribute_map = {
        'collect_time': 'collect_time',
        'content': 'content'
    }

    def __init__(self, collect_time=None, content=None):
        r"""LogContentDto

        The model defined in huaweicloud sdk

        :param collect_time: 作业日志采集时间
        :type collect_time: str
        :param content: 作业日志内容
        :type content: str
        """
        
        

        self._collect_time = None
        self._content = None
        self.discriminator = None

        if collect_time is not None:
            self.collect_time = collect_time
        if content is not None:
            self.content = content

    @property
    def collect_time(self):
        r"""Gets the collect_time of this LogContentDto.

        作业日志采集时间

        :return: The collect_time of this LogContentDto.
        :rtype: str
        """
        return self._collect_time

    @collect_time.setter
    def collect_time(self, collect_time):
        r"""Sets the collect_time of this LogContentDto.

        作业日志采集时间

        :param collect_time: The collect_time of this LogContentDto.
        :type collect_time: str
        """
        self._collect_time = collect_time

    @property
    def content(self):
        r"""Gets the content of this LogContentDto.

        作业日志内容

        :return: The content of this LogContentDto.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        r"""Sets the content of this LogContentDto.

        作业日志内容

        :param content: The content of this LogContentDto.
        :type content: str
        """
        self._content = content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogContentDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
